@@ -22,9 +22,9 @@ public:
 
     Private(const Private &other)
         : QSharedData(other)
+        , begin(other.begin)
+        , end(other.end)
     {
-        begin = other.begin;
-        end = other.end;
     }
 
     Id begin;
@@ -40,8 +40,8 @@ public:
     }
     Private(const Private &other)
         : QSharedData(other)
+        , intervals(other.intervals)
     {
-        intervals = other.intervals;
     }
 
     ImapInterval::List intervals;
@@ -217,7 +217,7 @@ bool ImapSet::operator==(const ImapSet &other) const
         return false;
     }
 
-    for (const ImapInterval &interval : qAsConst(d->intervals)) {
+    for (const ImapInterval &interval : std::as_const(d->intervals)) {
         if (!other.d->intervals.contains(interval)) {
             return false;
         }
@@ -263,7 +263,7 @@ QByteArray ImapSet::toImapSequenceSet() const
 {
     QList<QByteArray> rv;
     rv.reserve(d->intervals.count());
-    for (const ImapInterval &interval : qAsConst(d->intervals)) {
+    for (const ImapInterval &interval : std::as_const(d->intervals)) {
         rv << interval.toImapSequence();
     }
 
@@ -288,7 +288,7 @@ ImapSet ImapSet::fromImapSequenceSet(const QByteArray &sequence)
 
     const QList<QByteArray> intervals = sequence.split(',');
 
-    for (const QByteArray &interval : qAsConst(intervals)) {
+    for (const QByteArray &interval : std::as_const(intervals)) {
         if (!interval.isEmpty()) {
             result.add(ImapInterval::fromImapSequence(interval));
         }
